=====
Tools
=====

A tool in Pharmpy is an implementation of a pharmacometric method. A tool performs some kind of preprocessing, running of models, postprocessing and creation of results in the form of a workflow. Currently no complete tools are implemented in Pharmpy, but only parts of some PsN tools. These are documented here.

.. toctree::
   :maxdepth: 1

   bootstrap
   cdd
   crossval
   frem
   linearize
   modelsearch
   qa
   resmod
   scm
   simeval
